=== modified file 'NEWS'
--- NEWS	2008-08-20 22:34:59 +0000
+++ NEWS	2008-09-10 00:02:06 +0000
@@ -8,6 +8,9 @@
 
     - Fixed broken template for project browsing with start-loggerhead
       (Martin Albisett)
+      
+    - Added --reload options to restart the application when a python 
+      file change. (Guillermo Gonzalez) 
 
 1.6 [15Aug2008]
 ----------------

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2008-08-06 21:25:24 +0000
+++ loggerhead/util.py	2008-09-10 00:02:06 +0000
@@ -33,6 +33,9 @@
 import threading
 import time
 import types
+import sys
+import os
+import subprocess
 
 log = logging.getLogger("loggerhead.controllers")
 
@@ -445,3 +448,66 @@
     overrides = dict((k, v) for (k, v) in overrides.iteritems() if k in _valid)
     map.update(overrides)
     return map
+
+
+class Reloader(object):
+    """
+    This class wraps all paste.reloader logic. All methods are @classmethod.
+    """
+
+    _reloader_environ_key = 'PYTHON_RELOADER_SHOULD_RUN'
+
+    @classmethod
+    def _turn_sigterm_into_systemexit(self):
+        """
+        Attempts to turn a SIGTERM exception into a SystemExit exception.
+        """
+        try:
+            import signal
+        except ImportError:
+            return
+        def handle_term(signo, frame):
+            raise SystemExit
+        signal.signal(signal.SIGTERM, handle_term)
+
+    @classmethod
+    def is_installed(self):
+        return os.environ.get(self._reloader_environ_key)
+    
+    @classmethod
+    def install(self):
+        from paste import reloader
+        reloader.install(int(1))
+    
+    @classmethod    
+    def restart_with_reloader(self):
+        """Based on restart_with_monitor from paste.script.serve."""
+        print 'Starting subprocess with file monitor'
+        while 1:
+            args = [sys.executable] + sys.argv
+            new_environ = os.environ.copy()
+            new_environ[self._reloader_environ_key] = 'true'
+            proc = None
+            try:
+                try:
+                    self._turn_sigterm_into_systemexit()
+                    proc = subprocess.Popen(args, env=new_environ)
+                    exit_code = proc.wait()
+                    proc = None
+                except KeyboardInterrupt:
+                    print '^C caught in monitor process'
+                    return 1
+            finally:
+                if (proc is not None
+                    and hasattr(os, 'kill')):
+                    import signal
+                    try:
+                        os.kill(proc.pid, signal.SIGTERM)
+                    except (OSError, IOError):
+                        pass
+                
+            # Reloader always exits with code 3; but if we are
+            # a monitor, any exit code will restart
+            if exit_code != 3:
+                return exit_code
+            print '-'*20, 'Restarting', '-'*20
\ No newline at end of file

=== modified file 'serve-branches'
--- serve-branches	2008-09-09 22:45:53 +0000
+++ serve-branches	2008-09-10 00:02:06 +0000
@@ -28,8 +28,8 @@
 from loggerhead import __version__
 from loggerhead.apps.filesystem import (
     BranchesFromFileSystemRoot, UserBranchesFromFileSystemRoot)
+from loggerhead.util import Reloader
 
-_reloader_environ_key = 'PYTHON_RELOADER_SHOULD_RUN'
 
 def command_line_parser():
     parser = OptionParser("%prog [options] <path>")
@@ -48,7 +48,8 @@
     parser.add_option("--prefix", dest="user_prefix",
                       help="Specify host prefix.")
     parser.add_option("--reload", action="store_true", dest="reload",
-                      help="Use a file monitor to restart the application")
+                      help="Restarts the application when changing python"
+                           " files. Only used for development purposes.")
     parser.add_option("--version", action="store_true", dest="show_version",
                       help="Print the software version and exit")
     return parser
@@ -82,11 +83,10 @@
         sys.exit(1)
         
     if options.reload:
-        if os.environ.get(_reloader_environ_key):
-            from paste import reloader
-            reloader.install(int(1))
+        if Reloader.is_installed():
+            Reloader.install()
         else:
-            return restart_with_reloader()
+            return Reloader.restart_with_reloader()
 
     if options.user_dirs:
         if not options.trunk_dir:
@@ -121,40 +121,6 @@
         host = options.user_host
 
     httpserver.serve(app, host=host, port=port)
-    
-
-def restart_with_reloader():
-    print 'Starting subprocess with file monitor'
-    while 1:
-        args = [sys.executable] + sys.argv
-        new_environ = os.environ.copy()
-        new_environ[_reloader_environ_key] = 'true'
-        proc = None
-        try:
-            try:
-                import paste.script.serve
-                import subprocess
-                paste.script.serve._turn_sigterm_into_systemexit()
-                proc = subprocess.Popen(args, env=new_environ)
-                exit_code = proc.wait()
-                proc = None
-            except KeyboardInterrupt:
-                print '^C caught in monitor process'
-                return 1
-        finally:
-            if (proc is not None
-                and hasattr(os, 'kill')):
-                import signal
-                try:
-                    os.kill(proc.pid, signal.SIGTERM)
-                except (OSError, IOError):
-                    pass
-            
-        # Reloader always exits with code 3; but if we are
-        # a monitor, any exit code will restart
-        if exit_code != 3:
-            return exit_code
-        print '-'*20, 'Restarting', '-'*20
 
 
 if __name__ == "__main__":

=== modified file 'serve-branches.1'
--- serve-branches.1	2008-08-05 16:07:16 +0000
+++ serve-branches.1	2008-09-10 00:02:06 +0000
@@ -21,6 +21,9 @@
 \fB\-\-trunk\-dir\fR=\fIDIR\fR
 The directory that contains the trunk branches.
 .TP
+\fB\-\-reload\fR
+Restarts the application when changing python files. Only used for development purposes.
+.TP
 \fB\-\-version\fR
 Print the software version and exit
 .SH "LICENSE"

